from setuptools import setup, find_packages

setup(
    name='py_quizlet_cram_stepthree',
    version='0.1',
    packages=find_packages(exclude=['tests*']),
    license='MIT',
    description='A package for taking quizlet and cram quizzes',
	url='https://github.com/jonahedmundson/py_quizlet_cram_stepthree/tree/main',
    author='Jonah Edmunson and Matthew Yau',
    author_email='jonahedmundson@gmail.com'
)
